create_clim_param_HW: create_clim_param_HW

Description Usage Arguments Value Author(s)

Description

Calculate the parameters to assess heat-wave daily status from a climatic time series monthly. Mean air temperature , mean relative humidity and extreme thermal values are required. Parameters

Usage

1
2
3
create_clim_param_HW(data, name, index = "ATI", yiniclim = "1981",
  yfinclim = "2010", PT = c(90, 95, 98), window_days = 15,
  save_clim = F)

Arguments

data

data.frame Daily time series with colums' names: date(YYYY-MM-DD),tmed,tmax,tmin,rhum,vmed.

name

character Name of location or ID of time series.

index

character Biometerological index to calculate apparent temperature.

yfinclim

character Final year of climatological reference time period, Default is "2010".

PT

numeric Three levels of percentile used as thresholds for intensity. Default are c(90, 95, 98).

window_days

numeric Half Day span to calculate daily climatology. Default is 15.

save_clim

logical If True save file daily and montly in RDS and CSV format. Default is F.

iniclim

character Initial year of climatological reference time period, Default is "1981".

Value

Return a list of data.frame respectively with monthly and daily values.

Author(s)

Istituto di Biometeorologia Firenze Italy Alfonso Crisci a.crisci@ibimet.cnr.it


alfcrisci/rHeatWave documentation built on May 28, 2019, 4:54 p.m.