manage_GSOD: manage_GSOD

Description Usage Arguments Value Author(s)

Description

Download and build a specific data.frame for heatwave analisys from a GSOD NOAA repository station based on its unique USAF code.

Usage

1
2
manage_GSOD(id, name, ini_year = 1979, last_year = 2015, missing = NA,
  save_files = T)

Arguments

id

character USAF code of weather station.

name

character Name of location or ID of time series.

ini_year

character Initial year of data time period, Default is "1979".

last_year

character Final year of climatological reference time period, Default is "2016".

save_files

logical If True save GSOD data file in RDS and CSV format. Default is F.

Value

Return data.frame ready to use for heat-wave analitics.

Author(s)

Istituto di Biometeorologia Firenze Italy Alfonso Crisci a.crisci@ibimet.cnr.it


alfcrisci/rHeatWave documentation built on May 28, 2019, 4:54 p.m.