Description Usage Arguments Format Value Author(s) Source References
Main features of a selected GSOD italian weather station.
Geographical information of a selected GSOD italian weather station.
1 2 3 | calculate_HWdays(data, clim_array, method = "EuroHeat", index = "ATI",
wind = T, months = c(5:9), P_intesity = c(95), duration = 2,
time_reference = "DAY")
|
data |
data.frame Daily time series with colums' names: date(YYYY-MM-DD),tmed,tmax,tmin,rhum,vmed. |
clim_array |
data.frame Name of location or the time series analized. |
method |
character Method to assess critical and heatwave days. Default is "EuroHeat" and other are "TMAX","TMED","TMIN". |
index |
character Biometerological index to calculate apparent temperature with ATI or UTCI. Default is "ATI" corresponding to the shaded version of ATI Steadman (2004). |
wind |
logical If TRUE the wind in biometeorological index are considered. |
months |
numeric The month her HW days are calculated. Default are c(5:9) corresponding to May-Dec. |
P_intesity |
numeric If one of the "TMAX","TMED","TMIN" methods was selected is the level of intensity in term of percentiles.Default are c(95), |
duration |
numeric Minimum spell of critical days to be considered for heatave definition. Default is 2. |
time_reference |
numeric Temporal format of the referenced climatology: DAY (daily) or MON (monthly).Default is "DAY". |
data.frame
Return a list of data.frame respectively with monthly and daily values.
Istituto di Biometeorologia Firenze Italy Alfonso crisci a.crisci@ibimet.cnr.it
geo_selected_italian_weather
Istituto di Biometeorologia Firenze Italy Alfonso crisci a.crisci@ibimet.cnr.it
Istituto di Biometeorologia Firenze Italy Alfonso Crisci a.crisci@ibimet.cnr.it
https://data.noaa.gov/dataset/global-surface-summary-of-the-day-gsod
https://data.noaa.gov/dataset/global-surface-summary-of-the-day-gsod
Data are obtained from GSOD NOAA site. https://data.noaa.gov/dataset/global-surface-summary-of-the-day-gsod
Data are obtained from GSOD NOAA site. https://data.noaa.gov/dataset/global-surface-summary-of-the-day-gsod
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.