Description Usage Arguments Value Author(s)
Download and build a specific data.frame for heatwave analisys from a GSOD NOAA repository station based on its unique USAF code.
1 2 | manage_GSOD(id, name, ini_year = 1979, last_year = 2015, missing = NA,
save_files = T)
|
id |
character USAF code of weather station. |
name |
character Name of location or ID of time series. |
ini_year |
character Initial year of data time period, Default is "1979". |
last_year |
character Final year of climatological reference time period, Default is "2016". |
save_files |
logical If True save GSOD data file in RDS and CSV format. Default is F. |
Return data.frame ready to use for heat-wave analitics.
Istituto di Biometeorologia Firenze Italy Alfonso Crisci a.crisci@ibimet.cnr.it
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.